# -*- coding: UTF-8 -*-
from __future__ import print_function
from pyeole.ansiprint import print_color, print_orange, \
                             print_red, print_blue,     \
                             print_green, NOTPUT
import sys
import fcntl
import termios
import struct
from os import system

reload(sys)
sys.setdefaultencoding('utf-8')

def get_current_column():
    """Get current terminal column number.

        :return: number of columns
        :rtype: `list`
        :raises: if cannot detect columns number: IOError(25,
                 'Inappropriate ioctl for device')

    """
    try:
        data = fcntl.ioctl(sys.stdout.fileno(),
                termios.TIOCGWINSZ, u'1234')
        return struct.unpack('hh', data)[1]
    except (IOError, ValueError):
        return 80

def question_ouinon(question, interactive=True, default='non',
        default_uninteractive=None, level='info'):
    # conversion en str si unicode
    if type(default) == type(u""):
        default = default.encode('ascii','ignore')
    if type(default_uninteractive) == type(u""):
        default_uninteractive = default_uninteractive.encode('ascii', 'ignore')
    if type(question) == type(u""):
        question = question.encode('utf8')
    #attention, il faut synchroniser les modifications avec /usr/lib/eole/ihm.sh
    if default not in ['oui', 'non']:
        raise ValueError('question_ouinon : default doit être "oui" ou "non"')
    if default_uninteractive is None:
        default_uninteractive = default
    if default_uninteractive not in ['oui', 'non']:
        raise ValueError('question_ouinon : default doit être "oui" ou "non"')
    if level not in ['info', 'warn', 'err']:
        raise ValueError('question_ouinon : level doit être "info", "warn" ou "err"')
    #non-interactive
    if not interactive:
        return default_uninteractive
    question += ' [oui/non]'
    if level == 'info':
        print(question)
    elif level == 'warn':
        print_orange(question)
    else:
        print_red(question)
    rep = raw_input('[%s] : '%default)
    if default == 'non':
        if rep.lower() in ['o', 'oui', 'y', 'yes']:
            return "oui"
        else:
            return "non"
    else:
        if rep.lower() in ['n', 'non', 'no']:
            return "non"
        else:
            return "oui"

def print_title_rule(cols=None):
    """ print a title rule composed of '-'
    """
    if not cols:
        cols = get_current_column()

    try:
        print_blue('{:-^{col}}'.format('', col=cols))
    except ValueError:
        pass


def print_title(msg, cols=None):
    """ Print a title with this format :
        ###\t{message}\t###
    """
    if not cols:
        cols = get_current_column()

    try:
        output = u"{:^{col}}".format(msg, col=cols)
        print_title_rule()
        print_blue(output)
        print_title_rule()
    except ValueError:
        print(msg)

def print_no_cr(msg, column=None):
    """ print a line align on right without '\n'
    """
    if not column:
        column = get_current_column()

    try:
        fstr = "{:<{col}}".format(msg, col=column)
        sys.stdout.write(fstr)
        sys.stdout.flush()
    except ValueError:
        print(msg)

def print_line(msg, column=None):
    """ print a line align on right with '\n'
    """
    if not column:
        column = get_current_column()

    try:
        fstr = "{:<{col}}\n".format(msg, col=column)
        sys.stdout.write(fstr)
        sys.stdout.flush()
    except ValueError:
        print(msg)

def clear():
    """ Clear console if suitable
    """
    if not NOTPUT:
        system('clear')
